@@ -2,10 +2,12 @@ import os
 import xmlrpclib
 import sys
 import util
+import shutil
 import urllib 
 import urllib2
 import time
 import ConfigParser
+import optparse
 from glob import fnmatch
 from md5 import md5
 from BeautifulSoup import BeautifulSoup
@@ -273,11 +275,7 @@ class Mirror:
     def rmr(self, path):
         """ delete a package recursively (not really.)
         """
-        # delete files
-        for filename in os.listdir(path):
-            os.unlink(os.path.join(path, filename))
-        # delete dir
-        os.rmdir(path)
+        shutil.rmtree(path)
 
     def ls(self):
         filenames = []
@@ -536,30 +534,17 @@ def get_config_options(config_filename):
     config.read(config_filename)
     return config.defaults()
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 
 def run(args=None):
-    if args is None:
-        args = sys.argv[1:]
 
+    parser = optparse.OptionParser()
+    parser.add_option('-v', '--verbose', dest='verbose', action='store_true',
+                      default=False, help='verbose on')
+    parser.add_option('-i', '--indexes-only', dest='indexes_only', action='store_true',
+                      default=False, help='create indexes only (no mirroring)')
+    parser.add_option('-e', '--follow-external-links', dest='external_links', action='store_true',
+                      default=False, help='Follow and download external links)')
+    options, args = parser.parse_args()
     if len(args) != 1:
         print "Usage: mirror <config-file>"
         sys.exit(1)
@@ -572,12 +557,20 @@ def run(args=None):
     package_matches = config["package_matches"].split()
     cleanup = config["cleanup"] in ("True", "1")
     create_indexes = config["create_indexes"] in ("True", "1")
-    verbose = config["verbose"] in ("True", "1")
-    external_links = config["external_links"] in ("True", "1")
+    verbose = config["verbose"] in ("True", "1") or options.verbose
+    external_links = config["external_links"] in ("True", "1") or options.external_links
 
     package_list = PypiPackageList().list(package_matches)
     mirror = Mirror(config["mirror_file_path"])
     lock = zc.lockfile.LockFile(os.path.join(config["mirror_file_path"], config["lock_file_name"]))
-    mirror.mirror(package_list, filename_matches, verbose, cleanup, create_indexes, external_links, config["base_url"])
-
+    if options.indexes_only:
+        mirror.index_html()
+    else:
+        mirror.mirror(package_list, 
+                      filename_matches, 
+                      verbose, 
+                      cleanup, 
+                      create_indexes, 
+                      external_links, 
+                      config["base_url"])
 
